@@ -19,7 +19,7 @@ from typing import Dict, List, Optional, Text, Union
 import numpy as np
 import pandas as pd
 
-from .tags import Tags, TagSet
+from merlin.schema.tags import Tags, TagSet
 
 
 @dataclass(frozen=True)
@@ -35,7 +35,7 @@ class ColumnSchema:
 
     name: Text
     tags: Optional[TagSet] = field(default_factory=TagSet)
-    properties: Optional[Dict[str, any]] = field(default_factory=dict)
+    properties: Optional[Dict] = field(default_factory=dict)
     dtype: Optional[object] = None
     is_list: bool = False
     is_ragged: bool = False
@@ -233,7 +233,7 @@ class Schema:
     def column_names(self):
         return list(self.column_schemas.keys())
 
-    def apply(self, selector) -> "Schema":
+    def select(self, selector) -> "Schema":
         """Select matching columns from this Schema object using a ColumnSelector
 
         Parameters
@@ -256,7 +256,10 @@ class Schema:
             return schema
         return self
 
-    def apply_inverse(self, selector) -> "Schema":
+    def apply(self, selector) -> "Schema":
+        return self.select(selector)
+
+    def excluding(self, selector) -> "Schema":
         """Select non-matching columns from this Schema object using a ColumnSelector
 
         Parameters
@@ -270,9 +273,17 @@ class Schema:
             New object containing only the ColumnSchemas of selected columns
 
         """
-        if selector:
-            return self - self.select_by_name(selector.names)
-        return self
+        schema = self
+        if selector is not None:
+            if selector.names:
+                schema = schema.excluding_by_name(selector.names)
+            if selector.tags:
+                schema = schema.excluding_by_tag(selector.tags)
+
+        return schema
+
+    def apply_inverse(self, selector) -> "Schema":
+        return self.excluding(selector)
 
     def select_by_tag(self, tags: Union[Union[str, Tags], List[Union[str, Tags]]]) -> "Schema":
         """Select matching columns from this Schema object using a list of tags
@@ -299,7 +310,7 @@ class Schema:
 
         return Schema(selected_schemas)
 
-    def remove_by_tag(self, tags: Union[Union[str, Tags], List[Union[str, Tags]]]) -> "Schema":
+    def excluding_by_tag(self, tags) -> "Schema":
         if not isinstance(tags, (list, tuple)):
             tags = [tags]
 
@@ -311,7 +322,10 @@ class Schema:
 
         return Schema(selected_schemas)
 
-    def select_by_name(self, names: Union[List[str], str]) -> "Schema":
+    def remove_by_tag(self, tags) -> "Schema":
+        return self.excluding_by_tag(tags)
+
+    def select_by_name(self, names: List[str]) -> "Schema":
         """Select matching columns from this Schema object using a list of column names
 
         Parameters
@@ -333,25 +347,7 @@ class Schema:
         }
         return Schema(selected_schemas)
 
-    def remove_col(self, col_name: str) -> "Schema":
-        """Remove a column from this Schema object by name
-
-        Parameters
-        ----------
-        col_name : str
-            Name of the column to remove
-
-        Returns
-        -------
-        Schema
-            This Schema object after the column is removed
-
-        """
-        if col_name in self.column_names:
-            del self.column_schemas[col_name]
-        return self
-
-    def without(self, col_names: List[str]) -> "Schema":
+    def excluding_by_name(self, col_names: List[str]):
         """Remove columns from this Schema object by name
 
         Parameters
@@ -373,6 +369,25 @@ class Schema:
             ]
         )
 
+    def remove_col(self, col_name: str) -> "Schema":
+        """Remove a column from this Schema object by name
+
+        Parameters
+        ----------
+        col_name : str
+            Name of the column to remove
+
+        Returns
+        -------
+        Schema
+            This Schema object after the column is removed
+
+        """
+        return self.excluding_by_name([col_name])
+
+    def without(self, col_names: List[str]) -> "Schema":
+        return self.excluding_by_name(col_names)
+
     def get(self, col_name: str, default: ColumnSchema = None) -> ColumnSchema:
         """Get a ColumnSchema by name
 
@@ -431,6 +446,23 @@ class Schema:
     def __repr__(self):
         return str([col_schema.__dict__ for col_schema in self.column_schemas.values()])
 
+    def _repr_html_(self):
+        # Repr for Jupyter Notebook
+        return self.to_pandas()._repr_html_()
+
+    def to_pandas(self) -> pd.DataFrame:
+        """Convert this Schema object to a pandas DataFrame
+
+        Returns
+        -------
+        pd.DataFrame
+            DataFrame containing the column schemas in this Schema object
+
+        """
+        props = [c.__dict__ for c in self.column_schemas.values()]
+
+        return pd.json_normalize(props)
+
     def __eq__(self, other):
         if not isinstance(other, Schema) or len(self.column_schemas) != len(other.column_schemas):
             return False
